package com.ruoyi.business.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TbIdeaMapper;
import com.ruoyi.business.domain.TbIdea;
import com.ruoyi.business.service.ITbIdeaService;
import com.ruoyi.common.core.text.Convert;

/**
 * 意见反馈Service业务层处理
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Service
public class TbIdeaServiceImpl implements ITbIdeaService 
{
    @Autowired
    private TbIdeaMapper tbIdeaMapper;

    /**
     * 查询意见反馈
     * 
     * @param ideaId 意见反馈主键
     * @return 意见反馈
     */
    @Override
    public TbIdea selectTbIdeaByIdeaId(Long ideaId)
    {
        return tbIdeaMapper.selectTbIdeaByIdeaId(ideaId);
    }

    /**
     * 查询意见反馈列表
     * 
     * @param tbIdea 意见反馈
     * @return 意见反馈
     */
    @Override
    public List<TbIdea> selectTbIdeaList(TbIdea tbIdea)
    {
        return tbIdeaMapper.selectTbIdeaList(tbIdea);
    }

    /**
     * 新增意见反馈
     * 
     * @param tbIdea 意见反馈
     * @return 结果
     */
    @Override
    public int insertTbIdea(TbIdea tbIdea)
    {
        tbIdea.setCreateTime(DateUtils.getNowDate());
        return tbIdeaMapper.insertTbIdea(tbIdea);
    }

    /**
     * 修改意见反馈
     * 
     * @param tbIdea 意见反馈
     * @return 结果
     */
    @Override
    public int updateTbIdea(TbIdea tbIdea)
    {
        return tbIdeaMapper.updateTbIdea(tbIdea);
    }

    /**
     * 批量删除意见反馈
     * 
     * @param ideaIds 需要删除的意见反馈主键
     * @return 结果
     */
    @Override
    public int deleteTbIdeaByIdeaIds(String ideaIds)
    {
        return tbIdeaMapper.deleteTbIdeaByIdeaIds(Convert.toStrArray(ideaIds));
    }

    /**
     * 删除意见反馈信息
     * 
     * @param ideaId 意见反馈主键
     * @return 结果
     */
    @Override
    public int deleteTbIdeaByIdeaId(Long ideaId)
    {
        return tbIdeaMapper.deleteTbIdeaByIdeaId(ideaId);
    }
}
